@@ -39,7 +39,7 @@ class SignedPreKey(models.Model):
     cipher = models.CharField(max_length=88)
     salt = models.CharField(max_length=44)
     active = models.BooleanField(default=False)
-    # timestamp = UnixTimeStampField(auto_now_add=True)
+    timestamp = UnixTimeStampField(auto_now_add=True)
 
     class Meta:
         constraints = [models.UniqueConstraint(fields=['keyId', 'user'], name='unique_signed_prekey')]
